[Zope3-checkins] CVS: Zope3/src/zope/app/interfaces/index - field.py:1.4

Anthony Baxter anthony@interlink.com.au
Sat, 12 Jul 2003 23:36:07 -0400


Update of /cvs-repository/Zope3/src/zope/app/interfaces/index
In directory cvs.zope.org:/tmp/cvs-serv2618/app/interfaces/index

Modified Files:
	field.py 
Log Message:
Say hello to Mr. Catalog. 

Merge of the melb-2003-content-catalog-branch.

Currently, only FieldIndexes are hooked up to catalogs. Will be 
hooking up TextIndex next. Catalogs can be added as both Utilities 
(see zope/app/catalog/catalog.txt for details on doing this) and in
Content space.


=== Zope3/src/zope/app/interfaces/index/field.py 1.3 => 1.4 ===
--- Zope3/src/zope/app/interfaces/index/field.py:1.3	Mon Jun 23 12:44:39 2003
+++ Zope3/src/zope/app/interfaces/index/field.py	Sat Jul 12 23:36:03 2003
@@ -21,8 +21,8 @@
 from zope.app.component.interfacefield import InterfaceField
 
 
-class IUIFieldIndex(Interface):
-    """Interface for creating a FieldIndex from the ZMI."""
+class IUIFieldCatalogIndex(Interface):
+    """Interface for creating a FieldIndex in a catalog from the ZMI."""
 
     interface = InterfaceField(
                     title=u"Interface",
@@ -33,6 +33,9 @@
     field_name = BytesLine(
                     title=u"Field Name",
                     description=u"Name of the field to index")
+
+class IUIFieldIndex(IUIFieldCatalogIndex):
+    """Interface for creating a FieldIndex from the ZMI (not in a catalog)."""
 
     def subscribe():
         """Subscribe to the prevailing object hub service."""